@@ -5,13 +5,13 @@ from sklearn.neighbors import KDTree as SKKDTree
 from sklearn.cluster import AgglomerativeClustering as AggCluster
 from joblib import dump as jdump
 import numpy as np
+import hdbscan
 
 
 class AgglomerativeClustering(FTISAnalyser):
     def __init__(self, numclusters=3, cache=False):
         super().__init__(cache=cache)
         self.numclusters = numclusters
-        self.dump_type = ".json"
 
     def load_cache(self):
         self.output = read_json(self.dump_path)
@@ -58,7 +58,10 @@ class HDBSCAN(FTISAnalyser):
 
         data = np.array(values)
 
-        db = HdbscanClustering(min_cluster_size=self.minclustersize, min_samples=self.minsamples,).fit(data)
+        db = hdbscan.HDBSCAN(
+            min_cluster_size=self.minclustersize,
+            min_samples=self.minsamples,
+        ).fit(data)
 
         self.output = {}
 
