@@ -1,8 +1,9 @@
 from ftis.common.analyser import FTISAnalyser
 from ftis.common.io import write_json, read_json
 from ftis.common.proc import staticproc
-from umap import UMAP as umapdr
+from ftis.common.types import Data
 from joblib import dump as jdump
+from umap import UMAP as umapdr
 import numpy as np
 
 
@@ -15,7 +16,6 @@ class UMAP(FTISAnalyser):
         self.neighbours = neighbours
         self.components = components
         self.output = {}
-        self.dump_type = ".json"
 
     def load_cache(self):
         self.output = read_json(self.dump_path)
@@ -26,16 +26,23 @@ class UMAP(FTISAnalyser):
 
     def analyse(self):
         data = [v for v in self.input.values()]
-        keys = [k for k in self.input.keys()]
-
         data = np.array(data)
 
         self.model = umapdr(
-            n_components=self.components, n_neighbors=self.neighbours, min_dist=self.mindist, random_state=42
+            n_components=self.components, 
+            n_neighbors=self.neighbours, 
+            min_dist=self.mindist, 
+            random_state=42
         )
         self.model.fit(data)
         transformed_data = self.model.transform(data)
-        self.output = {k: v.tolist() for k, v in zip(keys, transformed_data)}
+        self.output = {
+            k: v.tolist() 
+            for k, v in zip(
+                self.input.keys(), 
+                transformed_data
+            )
+        }
 
     def run(self):
         staticproc(self.name, self.analyse)
