@@ -1,6 +1,6 @@
 from ftis.common.analyser import FTISAnalyser
 from ftis.common.io import write_json, read_json
-from ftis.common.proc import singleproc
+from ftis.common.proc import singleproc, multiproc
 from multiprocessing import Manager
 from scipy.signal import savgol_filter
 from scipy.io import wavfile
@@ -9,6 +9,9 @@ from sklearn.preprocessing import StandardScaler
 from flucoma import fluid
 from flucoma.utils import get_buffer
 import numpy as np
+from ftis.common.types import Indices
+import hdbscan
+from pathlib import Path
 
 
 class ClusteredNMF(FTISAnalyser):
@@ -67,7 +70,7 @@ class ClusteredNMF(FTISAnalyser):
 
         for x in unique_clusters:
             summed = np.zeros_like(sound[0])  # make an empty numpy array of same size
-            base = workable.name
+            base = Path(workable).name
             output = self.output / f"{base}_{x}.wav"
             for idx, cluster in enumerate(cluster_labels):
                 if cluster == x:
@@ -77,20 +80,18 @@ class ClusteredNMF(FTISAnalyser):
     def run(self):
         self.output = self.process.sink / f"{self.order}_{self.__class__.__name__}"
         self.output.mkdir(exist_ok=True)
-        workables = [
-            k for k in self.input.iterdir() if k.name != ".DS_Store" and k.is_file() and k.suffix == ".wav"
-        ]
-        singleproc(self.name, self.analyse, workables)
+        singleproc(self.name, self.analyse, self.input)
 
 
 class ClusteredSegmentation(FTISAnalyser):
-    def __init__(self, numclusters=2, windowsize=4, numderivs=0, fftsettings=[1024, -1 -1], cache=False):
+    def __init__(self, numclusters=2, windowsize=4, numderivs=0, fftsettings=[1024, -1, -1], cache=False):
         super().__init__(cache=cache)
+        self.input_type = (Indices, )
+        self.output_type = Indices
         self.numclusters = numclusters
         self.windowsize = windowsize
-        self.derivates = numderivs
+        self.numderivs = numderivs
         self.fftsettings = fftsettings 
-        self.dump_type = ".json"
 
     def load_cache(self):
         self.output = read_json(self.dump_path)
@@ -99,8 +100,7 @@ class ClusteredSegmentation(FTISAnalyser):
         write_json(self.dump_path, self.output)
 
     def analyse(self, workable):
-        slices = self.input[str(workable)]
-        slices = [int(x) for x in slices]
+        slices = self.input[workable]
         if len(slices) == 1:
             self.buffer[workable] = slices
             return
@@ -111,13 +111,13 @@ class ClusteredSegmentation(FTISAnalyser):
         while (count + self.windowsize) <= len(slices):
             indices = slices[count : count + self.windowsize]  # create a section of the indices in question
             data = []
-            for i, (start, end) in enumerate(zip(indices, indices[1:])):
+            for _, (start, end) in enumerate(zip(indices, indices[1:])):
 
                 mfccs = fluid.mfcc(
                     workable,
                     fftsettings=self.fftsettings,
-                    startframe=start,
-                    numframes=end - start,
+                    startframe=int(start),
+                    numframes=int(end - start),
                 )
 
                 stats = get_buffer(fluid.stats(mfccs, numderivs=self.numderivs), "numpy")
@@ -141,5 +141,5 @@ class ClusteredSegmentation(FTISAnalyser):
 
     def run(self):
         self.buffer = Manager().dict()
-        singleproc(self.name, self.analyse, self.input)
-        self.output = dict(self.buffer)
+        multiproc(self.name, self.analyse, self.input)
+        self.output = dict(self.buffer)
\ No newline at end of file
