@@ -3,6 +3,7 @@ from ftis.common.io import write_json, read_json
 from ftis.common.proc import singleproc
 from multiprocessing import Manager
 from scipy.stats import describe
+from ftis.common.types import Data
 from math import sqrt
 import numpy as np
 
@@ -22,7 +23,6 @@ class Stats(FTISAnalyser):
         self.numderivs = numderivs
         self.flatten = flatten
         self.spec = spec
-        self.dump_type = ".json"
 
     def dump(self):
         write_json(self.dump_path, self.output)
@@ -57,13 +57,11 @@ class Stats(FTISAnalyser):
             for i in range(num_derivs):
                 deriv = np.diff(base_data, i + 1)
                 container.append(self.calc_stats(deriv, self.spec))
-
-        elif num_derivs <= 0:
+        else:
             container = self.calc_stats(base_data, self.spec)
         return container
 
     def analyse(self, workable):
-        # TODO: any dimensionality input
         element_container = []
         values = np.array(self.input[workable])
         if len(values.shape) < 2:  # single row we run the stats on that
@@ -76,10 +74,10 @@ class Stats(FTISAnalyser):
             element_container = np.array(element_container)
             element_container = element_container.flatten()
             element_container = element_container.tolist()
+
         self.buffer[workable] = element_container
 
     def run(self):
         self.buffer = Manager().dict()
-        workables = [x for x in self.input.keys()]
-        singleproc(self.name, self.analyse, workables)
+        singleproc(self.name, self.analyse, self.input)
         self.output = dict(self.buffer)
