@@ -12,7 +12,7 @@ from ftis.corpus import Corpus
 from shutil import rmtree
 
 class World:
-    def __init__(self, source=None, sink=None, quiet=False, clear=False):
+    def __init__(self, sink=None, quiet=False, clear=False):
         self.sink = Path(sink).expanduser().resolve()
         self.node_depth = 0
         # Input corpora objects
@@ -71,6 +71,7 @@ class World:
                 child.suborder = suborder
 
             self.build_connections(child)
+            
         if not isinstance(node, World):
             self.metadata["analyser"][node.identity["hash"]] = {
                 k: str(v) 
@@ -88,7 +89,7 @@ class World:
 
     def run(self):
         if not self.quiet:
-            version = "# **** FTIS v2.1.0a ****"
+            version = "# **** FTIS ****"
             self.console.print(Markdown(version))
             # Construct information table
             corpora_paths = Table(title="Corpora", box=box.HORIZONTALS, show_lines=True)
